==> tool_lifecycle_moodle51_2026012000.zip: lifecycle/step/setcustomfield/lang/de/lifecyclestep_setcustomfield.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Lang Strings for Custom field Step
 *
 * @package    lifecyclestep_setcustomfield
 * @copyright  2025 Ostfalia
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['action'] = 'Setze Feld auf';
$string['action_help'] = 'Wie soll das Kursfeld gesetzt werden?';
$string['customfield'] = 'Kursfeld';
$string['customfield_help'] = 'Der Schritt verändert das Kursfeld.';
$string['error.invalidvalue'] = 'Der Wert ist ungültig';

$string['plugindescription'] = 'Es wird ein bestimmtes Kursfeld gesetzt.';
$string['pluginname'] = 'Nutzerdefiniertes Kursfeld setzen - Schritt';
$string['privacy:metadata'] = 'Speichert keine personenbezogenen Daten';

$string['setempty'] = 'leer';
$string['settimestamp'] = 'aktuellen Zeitstempel (jetzt)';
$string['setvalue'] = 'festen Wert';

$string['value'] = 'Wert';
$string['value_help'] = 'Wert, auf den gesetzt werden soll (nur falls "fester Wert" ausgewählt ist). Bei Auswahlfelder kann dies sowohl der Index als auch der Wert selbst sein.';

==> tool_lifecycle_moodle51_2026012001.zip: lifecycle/step/setcustomfield/lang/de/lifecyclestep_setcustomfield.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Lang Strings for Custom field Step
 *
 * @package    lifecyclestep_setcustomfield
 * @copyright  2025 Ostfalia
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['action'] = 'Setze Feld auf';
$string['action_help'] = 'Wie soll das Kursfeld gesetzt werden?';
$string['customfield'] = 'Kursfeld';
$string['customfield_help'] = 'Der Schritt verändert das Kursfeld.';
$string['error.invalidvalue'] = 'Der Wert ist ungültig';
$string['nocustomfields_link'] = 'Link zum Anlegen von Nutzerdefinierten Kursfeldern';
$string['nocustomfields_warning'] = 'Keine passenden Felder gefunden!';
$string['plugindescription'] = 'Es wird ein bestimmtes Kursfeld gesetzt.';
$string['pluginname'] = 'Nutzerdefiniertes Kursfeld setzen - Schritt';
$string['privacy:metadata'] = 'Speichert keine personenbezogenen Daten';
$string['setempty'] = 'leer';
$string['settimestamp'] = 'aktuellen Zeitstempel (jetzt)';
$string['setvalue'] = 'festen Wert';
$string['value'] = 'Wert';
$string['value_help'] = 'Wert, auf den gesetzt werden soll (nur falls "fester Wert" ausgewählt ist). Bei Auswahlfelder kann dies sowohl der Index als auch der Wert selbst sein.';
